@@ -164,12 +164,6 @@ public class FormatData_gd extends ListResourceBundle {
                "HH:mm:ss",
                "HH:mm",
             };
-        final String[] metaValue_DateTimePatterns = new String[] {
-               "{1} {0}",
-               "{1} {0}",
-               "{1} {0}",
-               "{1} {0}",
-            };
         final String[] metaValue_buddhist_QuarterNarrows = new String[] {
                "1",
                "2",
@@ -177,18 +171,28 @@ public class FormatData_gd extends ListResourceBundle {
                "4",
             };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
-               "EEEE, d MMMM y G",
-               "d MMMM y G",
+               "EEEE, d'mh' MMMM y G",
+               "d'mh' MMMM y G",
                "d MMM y G",
                "d/M/y GGGGG",
             };
         final String[] metaValue_buddhist_DatePatterns = new String[] {
-               "EEEE, d MMMM y GGGG",
-               "d MMMM y GGGG",
+               "EEEE, d'mh' MMMM y GGGG",
+               "d'mh' MMMM y GGGG",
                "d MMM y GGGG",
                "d/M/y G",
             };
-        final String[] metaValue_roc_Eras = new String[] {
+        final String[] metaValue_japanese_DateTimePatterns = new String[] {
+               "{1} 'aig' {0}",
+               "{1} 'aig' {0}",
+               "",
+               "",
+            };
+        final String[] metaValue_java_time_roc_long_Eras = new String[] {
+               "Ro Ph. na S\u00ecne",
+               "M\u00edngu\u00f3",
+            };
+        final String[] metaValue_java_time_roc_Eras = new String[] {
                "Ro PnS",
                "M\u00edngu\u00f3",
             };
@@ -209,6 +213,7 @@ public class FormatData_gd extends ListResourceBundle {
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "bliadhna" },
+            { "rohg.NumberElements", metaValue_brah_NumberElements },
             { "calendarname.islamic-umalqura", "Am M\u00ecosachan Ioslamach (Umm al-Qura)" },
             { "arabext.NumberElements",
                 new String[] {
@@ -264,18 +269,13 @@ public class FormatData_gd extends ListResourceBundle {
                 }
             },
             { "japanese.TimePatterns", metaValue_TimePatterns },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "narrow.Eras",
                 new String[] {
                     "R",
                     "A",
                 }
             },
-            { "roc.long.Eras",
-                new String[] {
-                    "Ro Ph. na S\u00ecne",
-                    "M\u00edngu\u00f3",
-                }
-            },
             { "talu.NumberElements",
                 new String[] {
                     ".",
@@ -367,8 +367,16 @@ public class FormatData_gd extends ListResourceBundle {
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
-            { "DateTimePatterns", metaValue_DateTimePatterns },
+            { "DateTimePatterns",
+                new String[] {
+                    "{1} {0}",
+                    "{1} {0}",
+                    "{1} {0}",
+                    "{1} {0}",
+                }
+            },
             { "narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "gong.NumberElements", metaValue_brah_NumberElements },
             { "latn.NumberElements", metaValue_brah_NumberElements },
             { "MonthNarrows", metaValue_MonthNarrows },
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
@@ -445,7 +453,7 @@ public class FormatData_gd extends ListResourceBundle {
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "field.month", "m\u00ecos" },
             { "osma.NumberElements", metaValue_brah_NumberElements },
-            { "roc.Eras", metaValue_roc_Eras },
+            { "roc.Eras", metaValue_java_time_roc_Eras },
             { "field.second", "diog" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
@@ -458,6 +466,8 @@ public class FormatData_gd extends ListResourceBundle {
             },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Am M\u00ecosachan Ioslamach" },
+            { "gonm.NumberElements", metaValue_brah_NumberElements },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "knda.NumberElements",
                 new String[] {
                     ".",
@@ -488,6 +498,7 @@ public class FormatData_gd extends ListResourceBundle {
                     "NaN",
                 }
             },
+            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "brah.NumberElements", metaValue_brah_NumberElements },
@@ -505,7 +516,7 @@ public class FormatData_gd extends ListResourceBundle {
                     "000 mhillean",
                     "0 bhillean",
                     "00 bhillean",
-                    "000 billean",
+                    "000 bhillean",
                     "0 trillean",
                     "00 trillean",
                     "000 trillean",
@@ -611,6 +622,7 @@ public class FormatData_gd extends ListResourceBundle {
                 }
             },
             { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "java.time.roc.Eras", metaValue_java_time_roc_Eras },
             { "khmr.NumberElements",
                 new String[] {
                     ".",
@@ -628,8 +640,15 @@ public class FormatData_gd extends ListResourceBundle {
             },
             { "field.zone", "roinn-t\u00ecde" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.DateTimePatterns", metaValue_DateTimePatterns },
-            { "roc.narrow.Eras", metaValue_roc_Eras },
+            { "roc.narrow.Eras", metaValue_java_time_roc_Eras },
+            { "roc.DateTimePatterns",
+                new String[] {
+                    "{1} 'aig' {0}",
+                    "{1} 'aig' {0}",
+                    "{1} {0}",
+                    "{1} {0}",
+                }
+            },
             { "laoo.NumberElements",
                 new String[] {
                     ".",
@@ -718,6 +737,7 @@ public class FormatData_gd extends ListResourceBundle {
             },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "latha na seachdaine" },
+            { "islamic.DateTimePatterns", metaValue_japanese_DateTimePatterns },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
             { "japanese.QuarterNames", metaValue_QuarterNames },
@@ -873,6 +893,7 @@ public class FormatData_gd extends ListResourceBundle {
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
             { "islamic.TimePatterns", metaValue_TimePatterns },
+            { "japanese.DateTimePatterns", metaValue_japanese_DateTimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "uair a th\u00ecde" },
