@@ -318,14 +318,6 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
                "Ora din Insulele Falkland",
                "",
             };
-        final String[] Bhutan = new String[] {
-               "Ora Bhutanului",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Apia = new String[] {
                "Ora standard din Apia",
                "",
@@ -334,6 +326,14 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
                "Ora din Apia",
                "",
             };
+        final String[] Bhutan = new String[] {
+               "Ora Bhutanului",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Nauru = new String[] {
                "Ora din Nauru",
                "",
@@ -574,12 +574,12 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Colombia = new String[] {
-               "Ora standard a Columbiei",
+        final String[] Australia_Eastern = new String[] {
+               "Ora standard a Australiei Orientale",
                "",
-               "Ora de var\u0103 a Columbiei",
+               "Ora de var\u0103 a Australiei Orientale",
                "",
-               "Ora Columbiei",
+               "Ora Australiei Orientale",
                "",
             };
         final String[] French_Guiana = new String[] {
@@ -590,12 +590,12 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "Ora standard a Australiei Orientale",
+        final String[] Colombia = new String[] {
+               "Ora standard a Columbiei",
                "",
-               "Ora de var\u0103 a Australiei Orientale",
+               "Ora de var\u0103 a Columbiei",
                "",
-               "Ora Australiei Orientale",
+               "Ora Columbiei",
                "",
             };
         final String[] Chile = new String[] {
@@ -1054,12 +1054,12 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Ora standard a Mexicului de nord-vest",
+        final String[] Volgograd = new String[] {
+               "Ora standard din Volgograd",
                "",
-               "Ora de var\u0103 a Mexicului de nord-vest",
+               "Ora de var\u0103 din Volgograd",
                "",
-               "Ora Mexicului de nord-vest",
+               "Ora din Volgograd",
                "",
             };
         final String[] Easter = new String[] {
@@ -1070,6 +1070,14 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
                "Ora din Insula Pa\u0219telui",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "Ora standard a Mexicului de nord-vest",
+               "",
+               "Ora de var\u0103 a Mexicului de nord-vest",
+               "",
+               "Ora Mexicului de nord-vest",
+               "",
+            };
         final String[] DumontDUrville = new String[] {
                "Ora din Dumont-d\u2019Urville",
                "",
@@ -1222,14 +1230,6 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
                "Ora din Samara",
                "",
             };
-        final String[] Pyongyang = new String[] {
-               "Ora din Pyongyang",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] India = new String[] {
                "Ora Indiei",
                "",
@@ -1260,7 +1260,16 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
             { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
@@ -1343,7 +1352,6 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
             { "Antarctica/McMurdo", New_Zealand },
             { "timezone.excity.America/Nome", "Nome" },
             { "Pacific/Tahiti", Tahiti },
-            { "HST", Hawaii_Aleutian },
             { "timezone.excity.America/Vancouver", "Vancouver" },
             { "timezone.excity.America/Matamoros", "Matamoros" },
             { "Africa/Asmera", Africa_Eastern },
@@ -1452,12 +1460,12 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
             { "timezone.excity.America/Sao_Paulo", "Sao Paulo" },
             { "Pacific/Gambier", Gambier },
             { "Africa/Gaborone", Africa_Central },
-            { "Asia/Pyongyang", Pyongyang },
+            { "Asia/Pyongyang", Korea },
             { "timezone.excity.America/New_York", "New York" },
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Africa/Accra", "Accra" },
             { "timezone.excity.Etc/Unknown", "Ora\u0219 necunoscut" },
-            { "Asia/Qyzylorda", Kazakhstan_Eastern },
+            { "Asia/Qyzylorda", Kazakhstan_Western },
             { "timezone.excity.America/Thule", "Thule" },
             { "timezone.excity.America/Grand_Turk", "Grand Turk" },
             { "America/Yakutat", Alaska },
@@ -1518,8 +1526,17 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
             { "Asia/Vladivostok", Vladivostok },
             { "timezone.excity.Atlantic/St_Helena", "Sf. Elena" },
             { "Africa/Maputo", Africa_Central },
-            { "Africa/El_Aaiun", Europe_Western },
             { "Africa/Ouagadougou", GMT },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
             { "timezone.excity.Europe/Luxembourg", "Luxemburg" },
             { "America/Cayman", America_Eastern },
@@ -1676,7 +1693,6 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
             { "timezone.excity.America/Goose_Bay", "Goose Bay" },
             { "timezone.excity.America/Eirunepe", "Eirunepe" },
             { "timezone.excity.America/Los_Angeles", "Los Angeles" },
-            { "MST", America_Mountain },
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Cuiaba" },
             { "Pacific/Noumea", New_Caledonia },
@@ -1713,6 +1729,7 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
             { "America/Caracas", Venezuela },
             { "Asia/Hebron", Europe_Eastern },
             { "SystemV/PST8PDT", America_Pacific },
+            { "timezone.excity.Asia/Qostanay", "Kostanay" },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Louisville", "Louisville" },
@@ -1884,7 +1901,7 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
             { "Asia/Yakutsk", Yakutsk },
@@ -1908,7 +1925,7 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "timezone.excity.Europe/Athens", "Atena" },
             { "Africa/Djibouti", Africa_Eastern },
-            { "EST", America_Eastern },
+            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
@@ -1930,6 +1947,7 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Jerusalem", "Ierusalim" },
             { "Atlantic/Faeroe", Europe_Western },
             { "timezone.excity.Asia/Riyadh", "Riad" },
+            { "Antarctica/Casey", Australia_Western },
             { "Europe/Copenhagen", Europe_Central },
             { "timezone.excity.Africa/Bangui", "Bangui" },
             { "timezone.excity.Africa/Lusaka", "Lusaka" },
@@ -2090,7 +2108,7 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
             { "Australia/Brisbane", Australia_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
             { "timezone.excity.Europe/Busingen", "Busingen" },
-            { "Europe/Volgograd", Moscow },
+            { "Europe/Volgograd", Volgograd },
             { "America/Lower_Princes", Atlantic },
             { "timezone.excity.Europe/Istanbul", "Istanbul" },
             { "America/Rio_Branco", Acre },
@@ -2102,7 +2120,6 @@ public class TimeZoneNames_ro extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Vladivostok", "Vladivostok" },
             { "Africa/Lusaka", Africa_Central },
             { "timezone.excity.Africa/Tunis", "Tunis" },
-            { "timezone.excity.Asia/Macau", "Macao" },
             { "America/Argentina/La_Rioja", Argentina },
             { "Africa/Dakar", GMT },
             { "SystemV/CST6CDT", America_Central },
